@@ -5,13 +5,13 @@ use strict;
 use warnings;
 use 5.10.0;
 
-our $VERSION = '0.11'; # TRIAL VERSION
+our $VERSION = '0.14'; # TRIAL VERSION
 
 use Config::Properties;
 use Data::Dumper;
 use File::HomeDir;
 use Log::Log4perl ':easy';
-use WWW::SFDC;
+use WWW::SFDC '0.33';
 
 use Moo::Role;
 use MooX::Options;
@@ -114,7 +114,7 @@ App::SFDC::Role::Credentials - Handle credential command-line input
 
 =head1 VERSION
 
-version 0.11
+version 0.14
 
 =head1 OPTIONS
 
@@ -150,11 +150,11 @@ for the operation.
 
 =head1 AUTHOR
 
-Alexander Brett <alexander.brett@sophos.com>
+Alexander Brett <alexander.brett@sophos.com> L<http://alexander-brett.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Sophos Limited.
+This software is Copyright (c) 2015 by Sophos Limited L<https://www.sophos.com/>.
 
 This is free software, licensed under:
 
